pub fn load_full_graph(conn: &Connection, db: &Database) -> KyuResult<GraphData>Expand description
Load all node tables and rel tables from the database.
pub fn load_full_graph(conn: &Connection, db: &Database) -> KyuResult<GraphData>Load all node tables and rel tables from the database.