pub fn launch(db: Database) -> Result<(), Box<dyn Error>>Expand description
Open the KyuGraph visualizer window with a pre-configured database.
Any tables already in db will be loaded into the canvas on startup.
Extensions must be registered on db before calling this function.