Module loader

Module loader 

Load graph data from KyuGraph catalog and query results.

Functions

format_typed_value
Format a TypedValue to a display string.
load_full_graph
Load all node tables and rel tables from the database.
load_node_table
Load all nodes from a specific node table into the graph.
load_rel_table
Load all relationships from a specific rel table into the graph.
load_schema
Load schema metadata from the catalog for the sidebar browser.