pub fn load_schema(db: &Database) -> SchemaDataExpand description
Load schema metadata from the catalog for the sidebar browser.
Queries actual row counts since the catalog num_rows may not reflect
rows inserted via individual CREATE statements.
pub fn load_schema(db: &Database) -> SchemaDataLoad schema metadata from the catalog for the sidebar browser.
Queries actual row counts since the catalog num_rows may not reflect
rows inserted via individual CREATE statements.